@@ -54,11 +54,13 @@
 #' old <- options(list(digits = 3, tibble.print_min = 64))
 #' library(dplyr, warn.conflicts = FALSE)
 #'
+#' try({#to avoid CRAN test problems
 #' nflseedR::load_sharpe_games() %>%
 #'   dplyr::filter(season %in% 2019:2020) %>%
 #'   dplyr::select(sim = season, game_type, week, away_team, home_team, result) %>%
 #'   nflseedR::compute_division_ranks() %>%
 #'   purrr::pluck("standings")
+#' })
 #'
 #' # Restore old options
 #' options(old)
@@ -70,9 +72,9 @@ compute_division_ranks <- function(games,
                                    h2h = NULL) {
   # catch invalid input
   if (!isTRUE(tiebreaker_depth %in% 1:3)) {
-    stop(
-      "The argument `tiebreaker_depth` has to be",
-      "a single value in the range of 1-3!"
+    cli::cli_abort(
+      "The argument {.arg tiebreaker_depth} has to be \\
+      a single value in the range of 1-3!"
     )
   }
 
@@ -86,11 +88,9 @@ compute_division_ranks <- function(games,
   )
 
   if (!sum(names(games) %in% required_vars, na.rm = TRUE) >= 6 | !is.data.frame(games)) {
-    stop(
-      "The argument `games` has to be a data frame including ",
-      "all of the following variables: ",
-      glue_collapse(required_vars, sep = ", ", last = " and "),
-      "!"
+    cli::cli_abort(
+      "The argument {.arg games} has to be a data frame including \\
+      all of the following variables: {.val {required_vars}}!"
     )
   }
 
@@ -192,7 +192,7 @@ compute_division_ranks <- function(games,
   while (any(is.na(teams$div_rank))) {
     # increment division rank
     dr <- dr + 1
-    report(paste0("Calculating division rank #", dr))
+    report("Calculating division rank #{dr}")
 
     # update teams with this rank
     update <- teams %>%
@@ -215,5 +215,8 @@ compute_division_ranks <- function(games,
   teams <- teams %>%
     mutate(max_reg_week = max_reg_week)
 
-  return(list(standings = teams, h2h = h2h))
+  list(
+    "standings" = tibble::as_tibble(teams),
+    "h2h" = tibble::as_tibble(h2h)
+  )
 }
