@@ -7,9 +7,9 @@ test_that("compute_division_ranks() works for multiple seasons", {
   ref <- readRDS("reference_div_ranks.rds")
 
   div_ranks <- g %>%
-    nflseedR::compute_division_ranks()
+    compute_division_ranks()
 
-  expect_identical(ref, div_ranks$standings)
+  expect_identical(div_ranks$standings, ref)
 })
 
 test_that("compute_conference_seeds() works for multiple seasons", {
@@ -19,10 +19,10 @@ test_that("compute_conference_seeds() works for multiple seasons", {
   ref <- readRDS("reference_conf_seeds.rds")
 
   conf_seeds <- g %>%
-    nflseedR::compute_division_ranks() %>%
-    nflseedR::compute_conference_seeds(h2h = .$h2h, playoff_seeds = 6)
+    compute_division_ranks() %>%
+    compute_conference_seeds(h2h = .$h2h, playoff_seeds = 6)
 
-  expect_identical(ref, conf_seeds$standings)
+  expect_identical(conf_seeds$standings, ref)
 })
 
 test_that("compute_draft_order() works for multiple seasons", {
@@ -32,9 +32,9 @@ test_that("compute_draft_order() works for multiple seasons", {
   ref <- readRDS("reference_draft_order.rds")
 
   draft_order <- g %>%
-    nflseedR::compute_division_ranks() %>%
-    nflseedR::compute_conference_seeds(h2h = .$h2h, playoff_seeds = 6) %>%
-    nflseedR::compute_draft_order(games = g, h2h = .$h2h)
+    compute_division_ranks() %>%
+    compute_conference_seeds(h2h = .$h2h, playoff_seeds = 6) %>%
+    compute_draft_order(games = g, h2h = .$h2h)
 
-  expect_identical(ref, draft_order)
+  expect_identical(draft_order, ref)
 })
